@@ -7,8 +7,6 @@ from contrast.utils.context_tracker import ContextTracker
 
 from contrast.assess_extensions import cs_str
 
-from contrast.extern.six import PY2
-
 
 __version__ = get_distribution("contrast-agent").version
 
@@ -27,8 +25,3 @@ SORTED_SYS_PATH = sorted(sys.path, key=len, reverse=True)
 # --- import aliases ---
 
 from contrast.agent.assess.utils import get_properties  # noqa
-
-if PY2:
-    from contrast.extern import pathlib2 as pathlib
-else:
-    import pathlib  # noqa
