@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
 
@@ -25,7 +25,7 @@ from .split_propagator import SplitPropagator
 @lru_cache(maxsize=10)
 def _get_regex_policy_node(method_name):
     policy = Policy()
-    patch_policy = policy.policy_by_name.get("re.Match.{}".format(method_name))
+    patch_policy = policy.policy_by_name.get(f"re.Match.{method_name}")
     return patch_policy.propagator_nodes[0] if patch_policy.propagator_nodes else None
 
 
