@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import cgi
 
-from contrast.extern.six import integer_types, iteritems, PY2
-from contrast.extern.six.moves.collections_abc import Mapping
+from collections.abc import Mapping
 
 import contrast
 from contrast.agent.assess.adjusted_span import AdjustedSpan
@@ -51,10 +50,17 @@ try:
 except ImportError:
     InMemoryUploadedFile_types = ()
 
+try:
+    from aiohttp.web_request import FileField
+
+    FileField_types = (FileField,)
+except ImportError:
+    FileField_types = ()
+
 
 @log_time("applying source policy")
 def apply(
-    source_nodes, self_obj, ret, args, kwargs=None
+    nodes, self_obj, ret, orig_args, orig_kwargs=None, **kwargs
 ):  # pylint: disable=redefined-builtin
     """
     Apply node into all sources to track all new strings coming in from a request
@@ -63,12 +69,12 @@ def apply(
     if context is None or not SettingsState().is_assess_enabled():
         return
 
-    for node in source_nodes:
+    for node in nodes:
 
         # args[0] is `self` for instance methods
-        args = args[1:] if node.instance_method else args
+        args = orig_args[1:] if node.instance_method else orig_args
 
-        target = node.get_matching_first_target(self_obj, ret, args, kwargs)
+        target = node.get_matching_first_target(self_obj, ret, args, orig_kwargs)
 
         source_type = node.type
         if isinstance(target, FileStorage_types):
@@ -77,7 +83,7 @@ def apply(
             # come out of a multidict, we track it. We need to track the underlying
             # stream, not the FileStorage object itself.
             if hasattr(target, "stream"):
-                target = target.stream if PY2 else target.stream._file
+                target = target.stream._file
             elif hasattr(target, "file"):
                 # starlette case
                 target = target.file
@@ -93,7 +99,7 @@ def apply(
                     self_obj,
                     ret,
                     args,
-                    kwargs,
+                    orig_kwargs,
                     source_type=source_type,
                 )
             target = target.file
@@ -109,7 +115,14 @@ def apply(
             set_properties(target, Properties(target))
 
         cs__apply_source(
-            context, node, target, self_obj, ret, args, kwargs, source_type=source_type
+            context,
+            node,
+            target,
+            self_obj,
+            ret,
+            args,
+            orig_kwargs,
+            source_type=source_type,
         )
 
 
@@ -308,7 +321,7 @@ def _cs__apply_source(
         # labeled with the appropriate data type (e.g. PARAMETER_KEY). This
         # behavior should not apply to recursive calls, however.
         source_key_type = key_type(source_type) if use_source_key else source_type
-        for key, value in iteritems(target):
+        for key, value in target.items():
             _cs__apply_source(
                 context,
                 node,
@@ -347,6 +360,19 @@ def _cs__apply_source(
         target._file.cs__source_type = "MULTIPART_CONTENT_DATA"
         target._file.cs__source_tags = node.tags
 
+    elif isinstance(target, FileField_types):
+        # circular import
+        from contrast.utils.assess.stream_utils import (
+            ContrastBufferedReaderProxy,
+        )  # noqa
+
+        # these instances are frozen using a library called `attr`. The library
+        # overrides __setattr__ for instances. The documented workaround is to use
+        # `object`'s __setattr__ instead
+        object.__setattr__(target, "file", ContrastBufferedReaderProxy(target.file))
+        target._file.cs__source_type = "MULTIPART_CONTENT_DATA"
+        target._file.cs__source_tags = node.tags
+
     elif is_iterable(target):
         for value in safe_iterator(target):
             _cs__apply_source(
@@ -373,7 +399,7 @@ def value_of_source(source, self_obj, ret, args, kwargs):
     if not args:
         return self_obj
 
-    if args and isinstance(source, integer_types) and source < len(args):
+    if args and isinstance(source, int) and source < len(args):
         return args[source]
 
     if kwargs and source in kwargs:
@@ -392,6 +418,26 @@ def get_parent_ids(node, self_obj, ret, args, kwargs):
     return get_last_event_ids_from_sources(sources)
 
 
+def build_source_node(source_dict, method_name, source_type, framework):
+    """
+    Useful for explicit source tracking, ie scope tracking / aiohttp request tracking.
+
+    Note that headers (including cookies) should not trigger XSS, per labs
+    """
+    tags = (
+        ["CROSS_SITE"] if source_type not in ["HEADER", "COOKIE"] else ["NO_NEWLINES"]
+    )
+
+    source_dict["method_name"] = method_name
+    source_dict["type"] = source_type
+    source_dict["tags"] = tags
+
+    node = SourceNode.from_dict(framework, source_dict)
+    node.skip_stacktrace = True
+
+    return node
+
+
 KEY_MAPPING = {
     "PARAMETER": "PARAMETER_KEY",
     "HEADER": "HEADER_KEY",
