@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from copy import copy
 import time
 
-from contrast.extern.six import iteritems
-
 import contrast
 from contrast.agent.assess.contrast_event import ContrastEvent
 from contrast.agent.assess.tag import (
@@ -122,7 +120,7 @@ class Properties(object):
 
         length = tag_range.length()
 
-        for key, value in iteritems(self.tags):
+        for key, value in self.tags.items():
 
             add = []
 
@@ -195,7 +193,7 @@ class Properties(object):
         merge_tags(self.tags)
 
         # delete empty lists
-        to_delete = [key for key, value in iteritems(self.tags) if not value]
+        to_delete = [key for key, value in self.tags.items() if not value]
         for key in to_delete:
             del self.tags[key]
 
@@ -217,8 +215,7 @@ class Properties(object):
         Convert Tag objects to TraceTaintRange objects for the service
         """
         ranges = []
-
-        for key, value in iteritems(self.tags):
+        for key, value in self.tags.items():
 
             if not value:
                 continue
@@ -380,8 +377,7 @@ class Properties(object):
         :return: None
         """
         full_delete = []
-
-        for key, tags in list(iteritems(self.tags)):
+        for key, tags in list(self.tags.items()):
             indexes_to_remove, tags_to_add = self._find_new_and_old_tags(
                 tags, tag_range
             )
