@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from pip._vendor import pkg_resources
 from collections import namedtuple
@@ -34,9 +34,7 @@ class DiscoverablePackage(object):
 
     @property
     def full_version(self):
-        return "{}.{}.{}".format(
-            self.version.major, self.version.minor, self.version.patch
-        )
+        return f"{self.version.major}.{self.version.minor}.{self.version.patch}"
 
     def set_info(self):
         framework = self.discover()
@@ -75,7 +73,7 @@ class DiscoverablePackage(object):
         return None
 
     def __repr__(self):
-        return "{} {}".format(self.name, self.full_version)
+        return f"{self.name} {self.full_version}"
 
 
 class Framework(DiscoverablePackage):
@@ -84,7 +82,7 @@ class Framework(DiscoverablePackage):
     """
 
     def __init__(self):
-        super(Framework, self).__init__(SUPPORTED_FRAMEWORKS, DEFAULT_FRAMEWORK)
+        super().__init__(SUPPORTED_FRAMEWORKS, DEFAULT_FRAMEWORK)
 
 
 class Server(DiscoverablePackage):
@@ -93,4 +91,4 @@ class Server(DiscoverablePackage):
     """
 
     def __init__(self):
-        super(Server, self).__init__(SUPPORTED_SERVERS, DEFAULT_SERVER)
+        super().__init__(SUPPORTED_SERVERS, DEFAULT_SERVER)
