@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
 import ast
@@ -106,14 +106,9 @@ class CoverageUtils(object):
         If there is no view function, like in the case of a pure WSGI app, then the func will
         be a string like '/sqli' and we just return that.
 
-        func_code is for PY2 and __code__ is for PY3
         """
         method_arg_names = "()"
-        if func is not None and hasattr(func, "func_code"):
-            method_arg_names = str(
-                func.func_code.co_varnames[0 : func.func_code.co_argcount]
-            ).replace("'", "")
-        elif func is not None and hasattr(func, "__code__"):
+        if func is not None and hasattr(func, "__code__"):
             method_arg_names = str(
                 func.__code__.co_varnames[0 : func.__code__.co_argcount]
             ).replace("'", "")
