@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from collections import deque
 from copy import copy
@@ -147,7 +147,7 @@ def create_django_routes():
 
 def _function_loc(func):
     """Return the function's module and name"""
-    return "{0.__module__}.{0.__name__}".format(func)
+    return f"{func.__module__}.{func.__name__}"
 
 
 def build_django_route(obj, method_arg_names=None):
