@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import copy
 from contrast.agent.middlewares.route_coverage.coverage_utils import (
     CoverageUtils,
     DEFAULT_ROUTE_METHODS,
 )
-from contrast.extern.six import PY2
 
 DEFAULT_ROUTE_METHODS = copy.copy(DEFAULT_ROUTE_METHODS) + ("PUT", "PATCH", "DELETE")
 
@@ -81,12 +80,11 @@ def get_view_method(cls_instance, request_method):
     :param request_method: string such as GET or POST
     :return: function: view method for the request_method, such as on_get for example above
     """
-    view_name = "on_{}".format(request_method.lower())
+    view_name = f"on_{request_method.lower()}"
     if hasattr(cls_instance, view_name):
         # use .__class__ and/or __func__ to get the unbound method
         view_func = getattr(cls_instance.__class__, view_name)
-        if PY2:
-            view_func = view_func.__func__
+
         return view_func
 
     return None
@@ -94,7 +92,5 @@ def get_view_method(cls_instance, request_method):
 
 def build_falcon_route(view_func, endpoint_cls):
     route_args = CoverageUtils.build_args_from_function(view_func)
-    route = "{}.{}{}".format(
-        endpoint_cls.__class__.__name__, view_func.__name__, route_args
-    )
+    route = f"{endpoint_cls.__class__.__name__}.{view_func.__name__}{route_args}"
     return route
