@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from collections import OrderedDict, defaultdict
 import json
@@ -117,8 +117,10 @@ class Policy(Singleton):
         for framework, nodes in self.policy_data[SOURCES_KEY].items():
             for value in nodes:
                 source_node = SourceNode.from_dict(framework, value)
-                if source_node.version_mismatch:
-                    continue
+
+                # Uncomment if we re-implement version_mismatch
+                # if source_node.version_mismatch:
+                #     continue
 
                 if source_node.should_apply():
                     self.sources.append(source_node)
@@ -127,8 +129,10 @@ class Policy(Singleton):
     def _load_propagators(self):
         for item in self.policy_data[PROPAGATION_KEY]:
             prop = PropagationNode.from_dict(item)
-            if prop.version_mismatch:
-                continue
+
+            # Uncomment if we re-implement version_mismatch
+            # if prop.version_mismatch:
+            #     continue
 
             self.propagators.append(prop)
             self.propagators_by_name[prop.name].append(prop)
