@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import PY2, PY3, integer_types
-
 from contrast.agent.policy import constants
 from contrast.agent.assess.assess_exceptions import ContrastAssessException
 from contrast.agent.policy.constants import ALL_ARGS, OBJECT, RETURN
@@ -25,8 +23,6 @@ class PolicyNode(object):
         target="",
         tags=None,
         policy_patch=True,
-        python2_only=False,
-        python3_only=False,
     ):
         self.module = module
         self.class_name = class_name
@@ -62,9 +58,6 @@ class PolicyNode(object):
         # purposes, but we don't want a policy patch.
         self.policy_patch = policy_patch
 
-        self.python2_only = python2_only
-        self.python3_only = python3_only
-
         self.skip_stacktrace = False
         self.properties = {}
 
@@ -75,7 +68,7 @@ class PolicyNode(object):
 
         Includes module name, class name (if applicable) and method name
         """
-        return "{}.{}".format(self.location, self.method_name)
+        return f"{self.location}.{self.method_name}"
 
     @property
     def location(self):
@@ -88,9 +81,7 @@ class PolicyNode(object):
         For a function:
             <module_path>.<function_name>
         """
-        return "{}{}".format(
-            self.module, "." + self.class_name if self.class_name else ""
-        )
+        return f"{self.module}{'.' + self.class_name if self.class_name else ''}"
 
     def add_property(self, name, value):
         if not name or not value:
@@ -111,10 +102,10 @@ class PolicyNode(object):
         """
         Indicates whether this node is incompatible with the current Python version
 
-        Currently the finest granularity we have is Py2.7 vs Py3, but eventually we may
+        Previously the finest granularity we have is Py2.7 vs Py3, but eventually we may
         update it to have more specific version specifications.
         """
-        return (PY2 and self.python3_only) or (PY3 and self.python2_only)
+        pass
 
     def parse_source_or_target(self, str_rep):
         """
@@ -198,7 +189,7 @@ class PolicyNode(object):
         if node_target == OBJECT:
             return self_obj
 
-        if args and isinstance(node_target, integer_types):
+        if args and isinstance(node_target, int):
             return args[node_target]
 
         return kwargs.get(node_target) if kwargs else None
@@ -206,16 +197,12 @@ class PolicyNode(object):
     def validate(self):
         if not self.module:
             raise ContrastAssessException(
-                "{} unknown did not have a proper module. Unable to create.".format(
-                    self.node_class
-                )
+                f"{self.node_class} unknown did not have a proper module. Unable to create."
             )
 
         if not self.method_name:
             raise ContrastAssessException(
-                "{} did not have a proper method name. Unable to create.".format(
-                    self.node_class
-                )
+                f"{self.node_class} did not have a proper method name. Unable to create."
             )
 
         self.validate_tags()
@@ -229,9 +216,7 @@ class PolicyNode(object):
                 item in constants.VALID_TAGS or item in constants.VALID_SOURCE_TAGS
             ):
                 raise ContrastAssessException(
-                    "{} {} had an invalid tag. {} is not a known value.".format(
-                        self.node_class, self.name, item
-                    )
+                    f"{self.node_class} {self.name} had an invalid tag. {item} is not a known value."
                 )
 
     def _type_to_action(self, sources_or_targets):
@@ -282,4 +267,4 @@ class PolicyNode(object):
         return event_action
 
     def __repr__(self):
-        return "{} - {}".format(self.__class__.__name__, self.name)
+        return f"{self.__class__.__name__} - {self.name}"
