@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import inspect
 import os
@@ -8,13 +8,13 @@ import contrast
 from contrast.api.dtm_pb2 import AttackResult, RaspRuleSample, UserInput
 from contrast.api.settings_pb2 import ProtectionRule
 from contrast.api.settings_pb2 import InputAnalysisResult
-from contrast.extern import six
 from contrast.utils.decorators import fail_safely, fail_quietly
 from contrast.utils.decorators import cached_property
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.stack_trace_utils import build_and_clean_stack
 from contrast.utils.timer import now_ms
 from contrast.extern import structlog as logging
+from contrast.utils.string_utils import ensure_string
 
 logger = logging.getLogger("contrast")
 
@@ -63,7 +63,7 @@ class BaseRule(object):
 
     @cached_property
     def config_rule_path_mode(self):
-        return "protect.rules.{}.mode".format(self.name)
+        return f"protect.rules.{self.name}.mode"
 
     def mode_from_config(self):
         """
@@ -193,9 +193,7 @@ class BaseRule(object):
         self._append_to_activity(attack)
 
         if self.should_block(attack):
-            raise SecurityException(
-                self, "Rule triggered. {} blocked.".format(match_string)
-            )
+            raise SecurityException(self, f"Rule triggered. {match_string} blocked.")
 
     @fail_safely("Failed to run protect rule")
     def protect(self, patch_policy, user_input, args, kwargs):
@@ -231,7 +229,7 @@ class BaseRule(object):
         if not user_input:
             return True
 
-        if isinstance(user_input, (six.string_types, six.binary_type)):
+        if isinstance(user_input, (str, bytes)):
             return False
 
         logger.debug(
@@ -241,7 +239,7 @@ class BaseRule(object):
         return True
 
     def convert_input(self, user_input):
-        return six.ensure_str(user_input)
+        return ensure_string(user_input)
 
     def increase_query_count(self):
         """Only rules for database support increase the query count"""
@@ -266,7 +264,7 @@ class BaseRule(object):
 
         if self.should_block(attack):
             raise SecurityException(
-                self, "Rule triggered in postfilter. {} blocked.".format(self.name)
+                self, f"Rule triggered in postfilter. {self.name} blocked."
             )
 
     def find_attack(self, candidate_string=None, analysis_stage=None, **kwargs):
@@ -390,13 +388,11 @@ class BaseRule(object):
             key = str(evaluation.key) if evaluation.key else ""
             input_type_name = UserInput.InputType.Name(evaluation.input_type)
 
-            rule_message = u"{} - {}".format(
-                self.name, six.ensure_text(evaluation.value, errors="replace")
+            rule_message = (
+                f"{self.name} - {ensure_string(evaluation.value, errors='replace')}"
             )
 
-            message = u"The {} {} had a value that successfully exploited: {}".format(
-                input_type_name, key, six.ensure_text(rule_message, errors="replace")
-            )
+            message = f"The {input_type_name} {key} had a value that successfully exploited: {ensure_string(rule_message, errors='replace')}"
         else:
             message = self.effective_attack_message()
 
@@ -412,17 +408,13 @@ class BaseRule(object):
 
             input_type_name = UserInput.InputType.Name(evaluation.input_type)
 
-            rule_message = u"{} - {}".format(
-                self.name, six.ensure_text(evaluation.value, errors="replace")
+            rule_message = (
+                f"{self.name} - {ensure_string(evaluation.value, errors='replace')}"
             )
 
             message = (
-                u"The {} {} had a value that matched a signature but did not"
-                u" exploit: {}".format(
-                    input_type_name,
-                    key,
-                    six.ensure_text(rule_message, errors="replace"),
-                )
+                f"The {input_type_name} {key} had a value that matched a signature but did not"
+                f" exploit: {ensure_string(rule_message, errors='replace')}"
             )
         else:
             message = self.effective_attack_message()
@@ -430,7 +422,7 @@ class BaseRule(object):
         logger.warning(message)
 
     def effective_attack_message(self):
-        return "An effective attack was detected against {}.".format(self.name)
+        return f"An effective attack was detected against {self.name}."
 
     def _append_to_activity(self, attack_result):
         """
@@ -452,9 +444,7 @@ class BaseRule(object):
 
         if response is None:
             raise Exception(
-                "Unable to convert Protect Mode to Attack Result {} Unknown Mode: {}".format(
-                    os.linesep, mode
-                )
+                f"Unable to convert Protect Mode to Attack Result {os.linesep} Unknown Mode: {mode}"
             )
 
         return response
@@ -479,5 +469,5 @@ class BaseRule(object):
             "Applying %s rule method %s with user input %s",
             self.name,
             method_name,
-            six.ensure_str(user_input, errors="replace"),
+            ensure_string(user_input, errors="replace"),
         )
