@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.protect.rule.base_rule import BaseRule
 from contrast.agent.protect.rule.deserialization.pickle_searcher import PickleSearcher
 from contrast.agent.protect.rule.deserialization.yaml_searcher import YAMLSearcher
 from contrast.api.dtm_pb2 import AttackResult, UserInput
 from contrast.api.settings_pb2 import InputAnalysisResult
-from contrast.extern import six
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.string_utils import ends_with_any
 from contrast.utils.stack_trace_utils import build_and_clean_stack
@@ -62,17 +61,15 @@ class Deserialization(BaseRule):
         if hasattr(user_input, "read"):
             return False
 
-        return super(Deserialization, self).skip_protect_analysis(
-            user_input, args, kwargs
-        )
+        return super().skip_protect_analysis(user_input, args, kwargs)
 
     def convert_input(self, user_input):
-        if isinstance(user_input, (six.string_types, six.binary_type)):
+        if isinstance(user_input, (str, bytes)):
             data = user_input
         else:
             data = self._get_stream_data(user_input)
 
-        return super(Deserialization, self).convert_input(data)
+        return super().convert_input(data)
 
     def _get_stream_data(self, user_input):
         """
@@ -113,7 +110,7 @@ class Deserialization(BaseRule):
         ):
             self.report_attack_without_finding(match_string, **kwargs)
 
-        return super(Deserialization, self).infilter(match_string, **kwargs)
+        return super().infilter(match_string, **kwargs)
 
     def find_attack(self, candidate_string=None, **kwargs):
         """
