@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast import AGENT_CURR_WORKING_DIR
-from contrast.extern.six import string_types
 from contrast.agent.protect.mixins.path_traversal_sink_features import (
     PathTraversalSinkFeatures,
 )
@@ -25,7 +24,7 @@ class PathTraversal(BaseRule, PathTraversalSinkFeatures):
         """
         Finds the attacker in the original string if present
         """
-        attack = super(PathTraversal, self).find_attack(
+        attack = super().find_attack(
             candidate_string, analysis_stage=analysis_stage, **kwargs
         )
         if analysis_stage == INFILTER and candidate_string:
@@ -62,7 +61,7 @@ def possible_write(args, kwargs):
 
 
 def actionable_path(path):
-    if not path or not isinstance(path, string_types):
+    if not path or not isinstance(path, str):
         return False
 
     # moving up directory structure is a risk and hence actionable
@@ -86,7 +85,7 @@ def actionable_path(path):
 
 def _safer_abs_paths():
     return (
-        ["{}/{}".format(AGENT_CURR_WORKING_DIR, item) for item in SAFE_PATHS]
+        [f"{AGENT_CURR_WORKING_DIR}/{item}" for item in SAFE_PATHS]
         if AGENT_CURR_WORKING_DIR
         else []
     )
