@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import ensure_binary, iteritems
 from contrast.agent import scope
 
 from contrast.agent.request import Request
@@ -10,17 +9,19 @@ from contrast.api.dtm_pb2 import Activity, ServerActivity, ObservedRoute
 
 from contrast.extern import structlog as logging
 
+from contrast.utils.string_utils import ensure_binary
+
 logger = logging.getLogger("contrast")
 
 
 class RequestContext(object):
-    def __init__(self, environ, body=None):
+    def __init__(self, environ):
 
         logger.debug("Initializing Request Context")
 
         scope.enter_contrast_scope()
 
-        self.request = Request(environ, body)
+        self.request = Request(environ)
 
         dtm = self.request.get_dtm()
         self.activity = Activity()
@@ -119,7 +120,7 @@ class RequestContext(object):
         #
         #   Example: Content-Type: text/html; charset=utf-8
         #   "CONTENT_TYPE" => Content-Type,["text/html; charset=utf8"]
-        for key, values in iteritems(response.headers.dict_of_lists()):
+        for key, values in response.headers.dict_of_lists().items():
             normalized_key = key.upper().replace("-", "_")
             response_headers = self.activity.http_response.normalized_response_headers
             response_headers[normalized_key].key = key
