@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+from copy import deepcopy
 import importlib.abc
 import importlib.machinery
 import importlib.util
@@ -14,7 +15,8 @@ from contrast.agent import scope
 from contrast.agent.assess.adjusted_span import AdjustedSpan
 from contrast.agent.assess.utils import clear_properties
 from contrast.agent.request_context import RequestContext
-from contrast.patches.rewriter import contrast__add
+from contrast.agent.settings_state import SettingsState
+from contrast.patches.rewriter import contrast__add, contrast__append
 from contrast.utils.decorators import fail_safely
 from contrast.utils.environ import test_environ
 from contrast.extern import structlog as logging
@@ -82,25 +84,36 @@ class ContrastRewriteLoader(importlib.abc.Loader):
         Note that we add our custom add function to the module's globals. This prevents
         the need for import rewriting entirely
         """
-        filename = module.__spec__.origin
-        with open(filename) as f:
-            source = f.read()
+        with scope.contrast_scope():
+            filename = module.__spec__.origin
+            with open(filename) as f:
+                source = f.read()
+
+            tree = ast.parse(source)
+            original_tree = deepcopy(tree)
+
+            if "contrast__add" not in module.__dict__:
+                try:
+                    module.__dict__["contrast__add"] = contrast__add
+                    module.__dict__["contrast__append"] = contrast__append
+                    ConcatRewriter().visit(tree)
+                    ast.fix_missing_locations(tree)
+                except Exception:
+                    logger.debug("WARNING: failed to rewrite %s", filename)
+            else:
+                logger.debug(
+                    "WARNING: contrast__add is already defined in %s; will not rewrite",
+                    filename,
+                )
 
-        tree = ast.parse(source)
-        if "contrast__add" not in module.__dict__:
             try:
-                module.__dict__["contrast__add"] = contrast__add
-                ConcatRewriter().visit(tree)
-                ast.fix_missing_locations(tree)
-            except Exception:
-                logger.debug("WARNING: failed to rewrite %s", filename)
-        else:
-            logger.warning(
-                "contrast__add is already defined in %s; will not rewrite", filename
-            )
+                co = compile(tree, filename, "exec", dont_inherit=True)
+            except (ValueError, TypeError):
+                # TODO: PYT-2086 consider safety benefit of keeping
+                # except Exception versus having to keep original_tree in memory
+                co = compile(original_tree, filename, "exec", dont_inherit=True)
 
-        co = compile(tree, filename, "exec", dont_inherit=True)
-        exec(co, module.__dict__)
+            exec(co, module.__dict__)
 
 
 class ConcatRewriter(ast.NodeTransformer):
@@ -123,6 +136,51 @@ class ConcatRewriter(ast.NodeTransformer):
         ast.copy_location(binop_replacement, binop)
         return binop_replacement
 
+    def visit_AugAssign(self, node: ast.AugAssign):
+        """
+        If we see an "Append", `+=` operation, replace it with a call to our custom
+        append function, which includes all necessary instrumentation.
+        """
+        self.visit(node.target)
+        self.visit(node.value)
+
+        if not isinstance(node.op, ast.Add):
+            return node
+
+        if isinstance(node.value, ast.Name):
+            value_id = node.value.id
+        elif isinstance(node.value, ast.Constant):
+            value_id = node.value.value
+        elif isinstance(node.value, ast.Attribute):
+            value_id = node.value.value
+        # TODO: PYT-2086 add else stmt
+
+        if isinstance(node.target, ast.Name):
+            target_id = node.target.id
+        elif isinstance(node.target, ast.Attribute):
+            # TODO: PYT-2086 this needs more work?
+            target_id = node.target.value.id
+        # TODO: PYT-2086 add else stmt
+
+        if not isinstance(target_id, str) or not isinstance(value_id, str):
+            # TODO: PYT-2086
+            return node
+
+        call_contrast_append_node = ast.Assign(
+            targets=[ast.Name(id=target_id, ctx=ast.Store())],
+            value=ast.Call(
+                func=ast.Name(id="contrast__append", ctx=ast.Load()),
+                args=[
+                    ast.Name(id=target_id, ctx=ast.Load()),
+                    ast.Name(id=value_id, ctx=ast.Load()),
+                ],
+                keywords=[],
+            ),
+        )
+
+        ast.copy_location(call_contrast_append_node, node)
+        return call_contrast_append_node
+
 
 @fail_safely("Unexpected error concat_works", log_level="debug", return_value=False)
 def concat_works():
@@ -173,6 +231,10 @@ def register():
         return
 
     sys.meta_path.insert(0, ContrastMetaPathFinder())
+
+    settings = SettingsState()
+    settings.rewriter_enabled = True
+
     logger.debug("enabled AST rewriter")
 
 
