@@ -2,6 +2,7 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
+from urllib.parse import urlparse
 
 from contrast import AGENT_CURR_WORKING_DIR
 from contrast.agent.framework import Framework, Server
@@ -38,6 +39,7 @@ class SettingsState(Singleton, SettingsREPMixin):
         self.framework = Framework()
         self.server = Server()
         self.sys_module_count = 0
+        self.rewriter_enabled = False
 
         # Features and Settings from Service
         self.server_features = ServerFeatures()
@@ -75,6 +77,20 @@ class SettingsState(Singleton, SettingsREPMixin):
             and self.server_features.defend.enabled
         )
 
+    @cached_property
+    def is_proxy_enabled(self):
+        proxy_enable = self.config.get("api.proxy.enable")
+        return bool(proxy_enable and str(proxy_enable).lower() in ("true"))
+
+    @cached_property
+    def proxy_url(self):
+        return self.config.get("api.proxy.url", None)
+
+    @cached_property
+    def proxy_scheme(self):
+        scheme = urlparse(self.proxy_url).scheme or "http"
+        return scheme
+
     @cached_property
     def api_service_key(self):
         return self.config.get("api.service_key")
@@ -361,3 +377,9 @@ class SettingsState(Singleton, SettingsREPMixin):
         return (
             self.config is not None and self.config.get("assess.stacktraces") == "NONE"
         )
+
+    def build_proxy_url(self):
+        if self.proxy_url:
+            return {self.proxy_scheme: self.proxy_url}
+
+        return {}
