@@ -68,6 +68,10 @@ class Telemetry(Singleton, threading.Thread):
         self._check_is_public_build()
         self._check_enabled()
 
+    @property
+    def wait_time(self):
+        return self.SLEEP
+
     @cached_property
     def instance_id(self):
         if self._mac_addr is None:
@@ -104,6 +108,8 @@ class Telemetry(Singleton, threading.Thread):
             # 100 is purely for safety; should be unlikely to hit.
             self.message_q = Queue(maxsize=100)
 
+            # Do not move creating startup msg outside of this function
+            # so the work stays in the telemetry thread, not the main thread.
             self.add_message(StartupMetricsTelemetryEvent())
 
             # This while loop should complete, shutting down the thread
@@ -112,7 +118,7 @@ class Telemetry(Singleton, threading.Thread):
                 if not self.message_q.empty():
                     self.send_message()
 
-                service_util.sleep(self.SLEEP)
+                service_util.sleep(self.wait_time)
 
     def add_message(self, msg):
         if not self.enabled or msg is None:
@@ -137,6 +143,7 @@ class Telemetry(Singleton, threading.Thread):
         response = post_request(
             url, json=data, headers=HEADERS, allow_redirects=False, verify=True
         )
+
         logger.debug("Telemetry response: %s %s", response.status_code, response.reason)
         return response
 
@@ -333,6 +340,7 @@ class MetricsTelemetryEvent(TelemetryEvent):
 class StartupMetricsTelemetryEvent(MetricsTelemetryEvent):
     def __init__(self):
         super().__init__()
+
         try:
             self.add_tags()
         except Exception as ex:
@@ -357,3 +365,6 @@ class StartupMetricsTelemetryEvent(MetricsTelemetryEvent):
         self.tags["app_framework_version"] = str(settings.framework)
         self.tags["server_framework_version"] = str(settings.server)
         self.tags["teamserver"] = settings.config.teamserver_type
+
+        if settings.rewriter_enabled:
+            self.tags["rewriter_enabled"] = "true"
