@@ -1,12 +1,10 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 This module contains workarounds for the fact that some builtin methods appear
 to be unpatchable using funchook for one reason or another.
 """
-from contrast.extern.six import binary_type, text_type
-
 import contrast
 from contrast.agent import scope
 from contrast.agent.policy import patch_manager
@@ -28,7 +26,7 @@ logger = logging.getLogger("contrast")
 def build_bytearray_join_patch(orig_method, patch_policy):
     node = patch_policy.propagator_nodes[0]
 
-    def bytearray_join_patch(self, *args, **kwargs):
+    def bytearray_join_patch(__cs_self, *args, **kwargs):
         # Since we need to make reference to the input multiple times, convert the
         # first argument to a list and use that instead. This prevents any iterators
         # from being exhausted before we can make use of them in propagation.
@@ -38,15 +36,15 @@ def build_bytearray_join_patch(orig_method, patch_policy):
         # iterator itself, in contrast to a tuple that contains that list or
         # iterator. (Got that straight?)
         if cs_str.in_contrast_or_propagation_scope():
-            return orig_method(self, *args, **kwargs)
+            return orig_method(__cs_self, *args, **kwargs)
 
         args_list = [list(args[0])] + list(args[1:])
-        result = orig_method(self, *args_list, **kwargs)
+        result = orig_method(__cs_self, *args_list, **kwargs)
 
         scope.enter_contrast_scope()
 
         try:
-            preshift = Preshift(self, args_list, kwargs)
+            preshift = Preshift(__cs_self, args_list, kwargs)
             propagator = JoinPropagator(node, preshift, result)
             if propagator.needs_propagation:
                 propagator.track_and_propagate(result)
@@ -64,19 +62,19 @@ def build_bytearray_join_patch(orig_method, patch_policy):
 def build_strtype_join_patch(orig_method, patch_policy):
     node = patch_policy.propagator_nodes[0]
 
-    def strtype_join_patch(self, *args, **kwargs):
+    def strtype_join_patch(__cs_self, *args, **kwargs):
         if cs_str.in_contrast_or_propagation_scope():
-            return orig_method(self, *args, **kwargs)
+            return orig_method(__cs_self, *args, **kwargs)
 
         args_list = list(args[0])
 
         with scope.propagation_scope():
-            result = orig_method(self, args_list, **kwargs)
+            result = orig_method(__cs_self, args_list, **kwargs)
 
         scope.enter_contrast_scope()
 
         try:
-            preshift = Preshift(self, (args_list,), kwargs)
+            preshift = Preshift(__cs_self, (args_list,), kwargs)
             propagator = JoinPropagator(node, preshift, result)
             if propagator.needs_propagation:
                 propagator.track_and_propagate(result)
@@ -94,7 +92,7 @@ def build_strtype_join_patch(orig_method, patch_policy):
 def build_str_format_patch(orig_method, patch_policy):
     node = patch_policy.propagator_nodes[0]
 
-    def str_format_patch(self, *args, **kwargs):
+    def str_format_patch(__cs_self, *args, **kwargs):
         """
         Propagation hook for str.format
 
@@ -104,14 +102,14 @@ def build_str_format_patch(orig_method, patch_policy):
         here. Eventually it may be possible to fit this back into the more general
         infrastructure if we overhaul the way that scope works.
         """
-        result = orig_method(self, *args, **kwargs)
+        result = orig_method(__cs_self, *args, **kwargs)
 
         if cs_str.in_contrast_or_propagation_scope():
             return result
 
         try:
             with scope.contrast_scope():
-                preshift = Preshift(self, args, kwargs)
+                preshift = Preshift(__cs_self, args, kwargs)
                 propagator = FormatPropagator(node, preshift, result)
 
             # This evaluation must not occur in scope. This is what enables us
@@ -134,7 +132,7 @@ def build_str_format_patch(orig_method, patch_policy):
 def build_str_formatmap_patch(orig_method, patch_policy):
     node = patch_policy.propagator_nodes[0]
 
-    def str_formatmap_patch(self, *args, **kwargs):
+    def str_formatmap_patch(__cs_self, *args, **kwargs):
         """
         Propagation hook for str.format_map
 
@@ -144,14 +142,14 @@ def build_str_formatmap_patch(orig_method, patch_policy):
         here. Eventually it may be possible to fit this back into the more general
         infrastructure if we overhaul the way that scope works.
         """
-        result = orig_method(self, *args, **kwargs)
+        result = orig_method(__cs_self, *args, **kwargs)
 
         if cs_str.in_contrast_or_propagation_scope() or not args:
             return result
 
         try:
             with scope.contrast_scope():
-                preshift = Preshift(self, (), args[0])
+                preshift = Preshift(__cs_self, (), args[0])
                 propagator = FormatPropagator(node, preshift, result)
 
             # This evaluation must not occur in scope. This is what enables us
@@ -175,11 +173,11 @@ def build_generic_strtype_patch(orig_method, patch_policy):
     node = patch_policy.propagator_nodes[0]
     propagator_class = PROPAGATOR_ACTIONS.get(node.action)
 
-    def str_patch(self, *args, **kwargs):
-        result = orig_method(self, *args, **kwargs)
+    def str_patch(__cs_self, *args, **kwargs):
+        result = orig_method(__cs_self, *args, **kwargs)
 
         # This special case does not apply to bytearrays
-        if result is self:
+        if result is __cs_self:
             return result
 
         if cs_str.in_contrast_or_propagation_scope():
@@ -188,7 +186,7 @@ def build_generic_strtype_patch(orig_method, patch_policy):
         scope.enter_contrast_scope()
 
         try:
-            preshift = Preshift(self, args, kwargs)
+            preshift = Preshift(__cs_self, args, kwargs)
             propagator = propagator_class(node, preshift, result)
 
             if propagator.needs_propagation:
@@ -209,21 +207,21 @@ def build_track_without_new_event_patch(orig_method, patch_policy):
     node = patch_policy.propagator_nodes[0]
     propagator_class = PROPAGATOR_ACTIONS.get(node.action)
 
-    def str_patch(self, *args, **kwargs):
-        result = orig_method(self, *args, **kwargs)
+    def str_patch(__cs_self, *args, **kwargs):
+        result = orig_method(__cs_self, *args, **kwargs)
 
         if cs_str.in_contrast_or_propagation_scope():
             return result
 
         # This special case applies to all bytearray methods and all .translate methods
-        if result == self:
-            track_copy_without_new_event(result, self)
+        if result == __cs_self:
+            track_copy_without_new_event(result, __cs_self)
             return result
 
         scope.enter_contrast_scope()
 
         try:
-            preshift = Preshift(self, args, kwargs)
+            preshift = Preshift(__cs_self, args, kwargs)
             propagator = propagator_class(node, preshift, result)
 
             if propagator.needs_propagation:
@@ -264,8 +262,8 @@ def property_setter(self, value):
 def enable_str_properties():
     strprop = property(fget=property_getter, fset=property_setter)
 
-    smart_setattr(text_type, "cs__properties", strprop)
-    smart_setattr(binary_type, "cs__properties", strprop)
+    smart_setattr(str, "cs__properties", strprop)
+    smart_setattr(bytes, "cs__properties", strprop)
     smart_setattr(bytearray, "cs__properties", strprop)
 
 
@@ -280,7 +278,7 @@ def patch_strtype_method(strtype, method_name):
         builder = build_str_format_patch
     elif method_name == "format_map":
         builder = build_str_formatmap_patch
-    elif method_name == "translate" and strtype is text_type:
+    elif method_name == "translate" and strtype is str:
         builder = build_track_without_new_event_patch
     else:
         builder = (
@@ -296,6 +294,6 @@ def unpatch_strtype_methods():
     """
     Replace all patched strtype methods with the original implementation
     """
-    patch_manager.reverse_patches_by_owner(text_type)
-    patch_manager.reverse_patches_by_owner(binary_type)
+    patch_manager.reverse_patches_by_owner(str)
+    patch_manager.reverse_patches_by_owner(bytes)
     patch_manager.reverse_patches_by_owner(bytearray)
