@@ -15,6 +15,9 @@ class BaseTsMessage:
         self.msg_name = None
         self.path = None
         self.base_url = f"{self.settings.api_url}/api/ng/"
+        self.proxy = (
+            self.settings.build_proxy_url() if self.settings.is_proxy_enabled else {}
+        )
 
         self.headers = {
             "Authorization": base64.b64encode(
