@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import copy
 from inspect import isclass
@@ -19,4 +19,4 @@ def safe_copy(value):
 
 
 def get_name(obj):
-    return "{0.__module__}.{0.__name__}".format(obj) if isclass(obj) else obj.__name__
+    return f"{obj.__module__}.{obj.__name__}" if isclass(obj) else obj.__name__
